@@ -2,7 +2,7 @@ package Brannigan;
 
 # ABSTRACT: Comprehensive, flexible system for validating and parsing input, mainly targeted at web applications.
 
-our $VERSION = "1.1";
+our $VERSION = "1.100001";
 $VERSION = eval $VERSION;
 
 use warnings;
@@ -13,10 +13,6 @@ use Brannigan::Tree;
 
 Brannigan - Comprehensive, flexible system for validating and parsing input, mainly targeted at web applications.
 
-=head1 VERSION
-
-version 1.1
-
 =head1 SYNOPSIS
 
 	use Brannigan;
@@ -846,9 +842,7 @@ L</"HOW SCHEMES LOOK"> for more info on schemes).
 sub new {
 	my $class = shift;
 
-	my $self = { map { $_->{name} => $_ } @_ };
-
-	return bless $self, $class;
+	return bless { map { $_->{name} => $_ } @_ }, $class;
 }
 
 =head1 OBJECT METHODS
@@ -899,13 +893,9 @@ sub process {
 		my ($self, $scheme, $params) = @_;
 
 		return unless $scheme && $params && ref $params eq 'HASH' && $self->{$scheme};
-		my $tree = $self->_build_tree($scheme, $self->{validations});
-		return $tree->process($params);
+		$self->_build_tree($scheme, $self->{validations})->process($params);
 	} else {
-		my ($scheme, $params) = @_;
-
-		my $tree = Brannigan::Tree->new($scheme);
-		return $tree->process($params);
+		Brannigan::Tree->new($_[0])->process($_[1]);
 	}
 }
 
@@ -926,8 +916,6 @@ sub custom_validation {
 	return unless $name && $code && ref $code eq 'CODE';
 
 	$self->{validations}->{$name} = $code;
-
-	return 1;
 }
 
 ############################
@@ -1059,14 +1047,21 @@ validation plugin (L<http://demos.usejquery.com/ketchup-plugin/>).
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2013 Ido Perlmuter.
+Copyright 2017 Ido Perlmuter
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-See http://dev.perl.org/licenses/ for more information.
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
 =cut
 
 1;
+__END__
