@@ -1,6 +1,6 @@
 package Brannigan::Tree;
 
-our $VERSION = "1.1";
+our $VERSION = "1.100001";
 $VERSION = eval $VERSION;
 
 use strict;
@@ -11,10 +11,6 @@ use Brannigan::Validations;
 
 Brannigan::Tree - A Brannigan validation/parsing scheme tree, possibly built from a series of inherited schemes.
 
-=head1 VERSION
-
-version 1.1
-
 =head1 DESCRIPTION
 
 This module is used internally by L<Brannigan>. Basically, a tree is a
@@ -49,16 +45,11 @@ of failed validations for each failed parameter.
 sub process {
 	my ($self, $params) = @_;
 
-	# validate the data
-	my $data = {};
-
 	my $rejects = $self->validate($params, $self->{params});
-	$data->{_rejects} = $rejects if $rejects;
+	my $data = $self->parse($params, $self->{params}, $self->{groups});
 
-	my $prs = $self->parse($params, $self->{params}, $self->{groups});
-	foreach (sort keys %$prs) {
-		$data->{$_} = $prs->{$_};
-	}
+	$data->{_rejects} = $rejects
+		if $rejects;
 
 	return $data;
 }
@@ -462,13 +453,19 @@ L<http://search.cpan.org/dist/Brannigan/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2013 Ido Perlmuter.
+Copyright 2017 Ido Perlmuter
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
 
-See http://dev.perl.org/licenses/ for more information.
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 
 =cut
 
